@@ -201,7 +201,7 @@ def GetMondrianBitmap():
 def GetMondrianImage():
     """ Returns a default image placeholder as a :class:`wx.Image`. """
 
-    stream = six.StringIO(GetMondrianData())
+    stream = six.BytesIO(GetMondrianData())
     return wx.Image(stream)
 
 
@@ -484,11 +484,11 @@ class PILImageHandler(object):
         pil.thumbnail(thumbnailsize)
         img = wx.Image(pil.size[0], pil.size[1])
 
-        img.SetData(pil.convert("RGB").tostring())
+        img.SetData(pil.convert("RGB").tobytes())
 
         alpha = False
         if "A" in pil.getbands():
-            img.SetAlpha(pil.convert("RGBA").tostring()[3::4])
+            img.SetAlpha(pil.convert("RGBA").tobytes()[3::4])
             alpha = True
 
         return img, originalsize, alpha
@@ -506,10 +506,10 @@ class PILImageHandler(object):
         import PIL.ImageEnhance as ImageEnhance
 
         pil = Image.new('RGB', (img.GetWidth(), img.GetHeight()))
-        pil.fromstring(img.GetData())
+        pil.frombytes(bytes(img.GetData()))
         enh = ImageEnhance.Brightness(pil)
         enh = enh.enhance(1.5)
-        img.SetData(enh.convert('RGB').tostring())
+        img.SetData(enh.convert('RGB').tobytes())
         return img
 
 
@@ -2457,7 +2457,7 @@ class ScrolledThumbnail(wx.ScrolledWindow):
                 fil = opj(thumb.GetFullFileName())
                 pil = Image.open(fil).rotate(newangle)
                 img = wx.Image(pil.size[0], pil.size[1])
-                img.SetData(pil.convert('RGB').tostring())
+                img.SetData(pil.convert('RGB').tobytes())
                 thumb.SetRotation(newangle*pi/180)
             else:
                 img = thumb._threadedimage
